@@ -16,7 +16,7 @@ from typeguard import check_type
 from ._jsii import *
 
 __all__ = [
-    "env",
+    "constructs",
     "stacks",
     "utils",
 ]
@@ -24,6 +24,6 @@ __all__ = [
 publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
-from . import env
+from . import constructs
 from . import stacks
 from . import utils
